pub fn enable_phy_clock<'d>() -> PhyClockGuard<'d>Expand description
Enable the PHY clock and acquire a PhyClockGuard.
The PHY clock will only be disabled once all PhyClockGuards are dropped.
pub fn enable_phy_clock<'d>() -> PhyClockGuard<'d>Enable the PHY clock and acquire a PhyClockGuard.
The PHY clock will only be disabled once all PhyClockGuards are dropped.